# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .access_point import *
from .api_key import *
from .business_metadata import *
from .business_metadata_binding import *
from .byok_key import *
from .catalog_entity_attributes import *
from .cluster_link import *
from .connector import *
from .custom_connector_plugin import *
from .dns_forwarder import *
from .dns_record import *
from .environment import *
from .flink_compute_pool import *
from .flink_statement import *
from .get_access_point import *
from .get_business_metadata import *
from .get_business_metadata_binding import *
from .get_byok_key import *
from .get_dns_record import *
from .get_environment import *
from .get_environments import *
from .get_flink_compute_pool import *
from .get_flink_region import *
from .get_gateway import *
from .get_group_mapping import *
from .get_identity_pool import *
from .get_identity_provider import *
from .get_invitation import *
from .get_ip_addresses import *
from .get_kafka_client_quota import *
from .get_kafka_cluster import *
from .get_kafka_topic import *
from .get_ksql_cluster import *
from .get_network import *
from .get_network_link_endpoint import *
from .get_network_link_service import *
from .get_organization import *
from .get_peering import *
from .get_private_link_access import *
from .get_private_link_attachment import *
from .get_private_link_attachment_connection import *
from .get_role_binding import *
from .get_schema import *
from .get_schema_registry_cluster import *
from .get_schema_registry_cluster_config import *
from .get_schema_registry_cluster_mode import *
from .get_schema_registry_clusters import *
from .get_schema_registry_dek import *
from .get_schema_registry_kek import *
from .get_schema_registry_region import *
from .get_schemas import *
from .get_service_account import *
from .get_subject_config import *
from .get_subject_mode import *
from .get_tag import *
from .get_tag_binding import *
from .get_transit_gateway_attachment import *
from .get_user import *
from .get_users import *
from .group_mapping import *
from .identity_pool import *
from .identity_provider import *
from .invitation import *
from .kafka_acl import *
from .kafka_client_quota import *
from .kafka_cluster import *
from .kafka_cluster_config import *
from .kafka_mirror_topic import *
from .kafka_topic import *
from .ksql_cluster import *
from .network import *
from .network_link_endpoint import *
from .network_link_service import *
from .peering import *
from .private_link_access import *
from .private_link_attachment import *
from .private_link_attachment_connection import *
from .provider import *
from .role_binding import *
from .schema import *
from .schema_exporter import *
from .schema_registry_cluster import *
from .schema_registry_cluster_config import *
from .schema_registry_cluster_mode import *
from .schema_registry_dek import *
from .schema_registry_kek import *
from .service_account import *
from .subject_config import *
from .subject_mode import *
from .tag import *
from .tag_binding import *
from .tf_importer import *
from .transit_gateway_attachment import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_confluentcloud.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_confluentcloud.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "confluentcloud",
  "mod": "index/accessPoint",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/accessPoint:AccessPoint": "AccessPoint"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/apiKey",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/businessMetadata",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/businessMetadata:BusinessMetadata": "BusinessMetadata"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/businessMetadataBinding",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/businessMetadataBinding:BusinessMetadataBinding": "BusinessMetadataBinding"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/byokKey",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/byokKey:ByokKey": "ByokKey"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/catalogEntityAttributes",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/catalogEntityAttributes:CatalogEntityAttributes": "CatalogEntityAttributes"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/clusterLink",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/clusterLink:ClusterLink": "ClusterLink"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/connector",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/connector:Connector": "Connector"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/customConnectorPlugin",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/customConnectorPlugin:CustomConnectorPlugin": "CustomConnectorPlugin"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/dnsForwarder",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/dnsForwarder:DnsForwarder": "DnsForwarder"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/dnsRecord",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/dnsRecord:DnsRecord": "DnsRecord"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/environment",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/flinkComputePool",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/flinkComputePool:FlinkComputePool": "FlinkComputePool"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/flinkStatement",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/flinkStatement:FlinkStatement": "FlinkStatement"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/groupMapping",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/groupMapping:GroupMapping": "GroupMapping"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/identityPool",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/identityPool:IdentityPool": "IdentityPool"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/identityProvider",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/invitation",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/invitation:Invitation": "Invitation"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaAcl",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaAcl:KafkaAcl": "KafkaAcl"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaClientQuota",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaClientQuota:KafkaClientQuota": "KafkaClientQuota"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaCluster",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaCluster:KafkaCluster": "KafkaCluster"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaClusterConfig",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaClusterConfig:KafkaClusterConfig": "KafkaClusterConfig"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaMirrorTopic",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaMirrorTopic:KafkaMirrorTopic": "KafkaMirrorTopic"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaTopic",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaTopic:KafkaTopic": "KafkaTopic"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/ksqlCluster",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/ksqlCluster:KsqlCluster": "KsqlCluster"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/network",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/network:Network": "Network"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/networkLinkEndpoint",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/networkLinkEndpoint:NetworkLinkEndpoint": "NetworkLinkEndpoint"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/networkLinkService",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/networkLinkService:NetworkLinkService": "NetworkLinkService"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/peering",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/peering:Peering": "Peering"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/privateLinkAccess",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/privateLinkAccess:PrivateLinkAccess": "PrivateLinkAccess"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/privateLinkAttachment",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/privateLinkAttachment:PrivateLinkAttachment": "PrivateLinkAttachment"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/privateLinkAttachmentConnection",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/privateLinkAttachmentConnection:PrivateLinkAttachmentConnection": "PrivateLinkAttachmentConnection"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/roleBinding",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/roleBinding:RoleBinding": "RoleBinding"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schema",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaExporter",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaExporter:SchemaExporter": "SchemaExporter"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryCluster",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryCluster:SchemaRegistryCluster": "SchemaRegistryCluster"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryClusterConfig",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryClusterConfig:SchemaRegistryClusterConfig": "SchemaRegistryClusterConfig"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryClusterMode",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryClusterMode:SchemaRegistryClusterMode": "SchemaRegistryClusterMode"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryDek",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryDek:SchemaRegistryDek": "SchemaRegistryDek"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryKek",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryKek:SchemaRegistryKek": "SchemaRegistryKek"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/serviceAccount",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/serviceAccount:ServiceAccount": "ServiceAccount"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/subjectConfig",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/subjectConfig:SubjectConfig": "SubjectConfig"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/subjectMode",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/subjectMode:SubjectMode": "SubjectMode"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/tag",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/tagBinding",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/tagBinding:TagBinding": "TagBinding"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/tfImporter",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/tfImporter:TfImporter": "TfImporter"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/transitGatewayAttachment",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/transitGatewayAttachment:TransitGatewayAttachment": "TransitGatewayAttachment"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "confluentcloud",
  "token": "pulumi:providers:confluentcloud",
  "fqn": "pulumi_confluentcloud",
  "class": "Provider"
 }
]
"""
)
